@@ -13,6 +13,7 @@ import itertools
 import math
 import sys
 import time
+import warnings
 from contextlib import contextmanager, nullcontext
 from random import Random
 from threading import RLock
@@ -790,9 +791,15 @@ def test_on_observation_no_override():
 
 @pytest.mark.parametrize("provider", [HypothesisProvider, PrngProvider])
 def test_provider_conformance(provider):
-    run_conformance_test(
-        provider, settings=settings(max_examples=20, stateful_step_count=20)
-    )
+    with warnings.catch_warnings():
+        # emitted by available_timezones() from st.timezone_keys() on 3.11+
+        # with tzdata installed. see https://github.com/python/cpython/issues/137841.
+        # Once cpython fixes this, we can remove this.
+        if sys.version_info >= (3, 11):
+            warnings.simplefilter("ignore", EncodingWarning)
+        run_conformance_test(
+            provider, settings=settings(max_examples=20, stateful_step_count=20)
+        )
 
 
 # see https://github.com/HypothesisWorks/hypothesis/issues/4462 and discussion
@@ -808,3 +815,8 @@ def test_backend_deadline_exceeded_raised_as_flaky_backend_failure():
 
         with pytest.raises(FlakyBackendFailure):
             f()
+
+
+def test_backend_cannot_proceed_raises_on_invalid_scope():
+    with pytest.raises(InvalidArgument):
+        BackendCannotProceed("not a valid scope")
